==> zio-aws-rekognition_2.12-5.17.151.2-sources.jar: zio/aws/rekognition/model/PersonDetail.scala <==
package zio.aws.rekognition.model
import zio.aws.rekognition.model.primitives.PersonIndex
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class PersonDetail(
    index: Option[PersonIndex] = None,
    boundingBox: Option[zio.aws.rekognition.model.BoundingBox] = None,
    face: Option[zio.aws.rekognition.model.FaceDetail] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.PersonDetail = {
    import PersonDetail.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.PersonDetail
      .builder()
      .optionallyWith(
        index.map(value => PersonIndex.unwrap(value): java.lang.Long)
      )(_.index)
      .optionallyWith(boundingBox.map(value => value.buildAwsValue()))(
        _.boundingBox
      )
      .optionallyWith(face.map(value => value.buildAwsValue()))(_.face)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.PersonDetail.ReadOnly =
    zio.aws.rekognition.model.PersonDetail.wrap(buildAwsValue())
}
object PersonDetail {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.PersonDetail
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.PersonDetail =
      zio.aws.rekognition.model.PersonDetail(
        index.map(value => value),
        boundingBox.map(value => value.asEditable),
        face.map(value => value.asEditable)
      )
    def index: Option[PersonIndex]
    def boundingBox: Option[zio.aws.rekognition.model.BoundingBox.ReadOnly]
    def face: Option[zio.aws.rekognition.model.FaceDetail.ReadOnly]
    def getIndex: ZIO[Any, AwsError, PersonIndex] =
      AwsError.unwrapOptionField("index", index)
    def getBoundingBox
        : ZIO[Any, AwsError, zio.aws.rekognition.model.BoundingBox.ReadOnly] =
      AwsError.unwrapOptionField("boundingBox", boundingBox)
    def getFace
        : ZIO[Any, AwsError, zio.aws.rekognition.model.FaceDetail.ReadOnly] =
      AwsError.unwrapOptionField("face", face)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.PersonDetail
  ) extends zio.aws.rekognition.model.PersonDetail.ReadOnly {
    override val index: Option[PersonIndex] = scala
      .Option(impl.index())
      .map(value => zio.aws.rekognition.model.primitives.PersonIndex(value))
    override val boundingBox
        : Option[zio.aws.rekognition.model.BoundingBox.ReadOnly] = scala
      .Option(impl.boundingBox())
      .map(value => zio.aws.rekognition.model.BoundingBox.wrap(value))
    override val face: Option[zio.aws.rekognition.model.FaceDetail.ReadOnly] =
      scala
        .Option(impl.face())
        .map(value => zio.aws.rekognition.model.FaceDetail.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.PersonDetail
  ): zio.aws.rekognition.model.PersonDetail.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rekognition_2.12-5.17.178.1-sources.jar: zio/aws/rekognition/model/PersonDetail.scala <==
package zio.aws.rekognition.model
import zio.aws.rekognition.model.primitives.PersonIndex
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PersonDetail(
    index: Optional[PersonIndex] = Optional.Absent,
    boundingBox: Optional[zio.aws.rekognition.model.BoundingBox] =
      Optional.Absent,
    face: Optional[zio.aws.rekognition.model.FaceDetail] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.PersonDetail = {
    import PersonDetail.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.PersonDetail
      .builder()
      .optionallyWith(
        index.map(value => PersonIndex.unwrap(value): java.lang.Long)
      )(_.index)
      .optionallyWith(boundingBox.map(value => value.buildAwsValue()))(
        _.boundingBox
      )
      .optionallyWith(face.map(value => value.buildAwsValue()))(_.face)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.PersonDetail.ReadOnly =
    zio.aws.rekognition.model.PersonDetail.wrap(buildAwsValue())
}
object PersonDetail {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.PersonDetail
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.PersonDetail =
      zio.aws.rekognition.model.PersonDetail(
        index.map(value => value),
        boundingBox.map(value => value.asEditable),
        face.map(value => value.asEditable)
      )
    def index: Optional[PersonIndex]
    def boundingBox: Optional[zio.aws.rekognition.model.BoundingBox.ReadOnly]
    def face: Optional[zio.aws.rekognition.model.FaceDetail.ReadOnly]
    def getIndex: ZIO[Any, AwsError, PersonIndex] =
      AwsError.unwrapOptionField("index", index)
    def getBoundingBox
        : ZIO[Any, AwsError, zio.aws.rekognition.model.BoundingBox.ReadOnly] =
      AwsError.unwrapOptionField("boundingBox", boundingBox)
    def getFace
        : ZIO[Any, AwsError, zio.aws.rekognition.model.FaceDetail.ReadOnly] =
      AwsError.unwrapOptionField("face", face)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.PersonDetail
  ) extends zio.aws.rekognition.model.PersonDetail.ReadOnly {
    override val index: Optional[PersonIndex] = zio.aws.core.internal
      .optionalFromNullable(impl.index())
      .map(value => zio.aws.rekognition.model.primitives.PersonIndex(value))
    override val boundingBox
        : Optional[zio.aws.rekognition.model.BoundingBox.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.boundingBox())
        .map(value => zio.aws.rekognition.model.BoundingBox.wrap(value))
    override val face: Optional[zio.aws.rekognition.model.FaceDetail.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.face())
        .map(value => zio.aws.rekognition.model.FaceDetail.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.PersonDetail
  ): zio.aws.rekognition.model.PersonDetail.ReadOnly = new Wrapper(impl)
}
